/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.view;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;

import kieker.webgui.common.IUserManagerFacade;
import kieker.webgui.common.Role;
import kieker.webgui.common.User;

/**
 * @author Nils Christian Ehmke
 */
public final class CurrentUserManagementBean {

	@Autowired
	private IUserManagerFacade userManagerFacade;
	/**
	 * This list contains all available users.
	 */
	private List<User> users = new ArrayList<User>();

	/**
	 * Default constructor. <b>Do not call this constructor manually. It will only be accessed by Spring.</b>
	 */
	public CurrentUserManagementBean() {
		// No code necessary
	}

	/**
	 * Setter for the property {@link CurrentUserManagementBean#userManagerFacade}.
	 * 
	 * @param userManagerFacade
	 *            The new value for the property.
	 */
	public void setUserManagerFacade(final IUserManagerFacade userManagerFacade) {
		this.userManagerFacade = userManagerFacade;
	}

	/**
	 * This method adds the given user to the database and informs about success via the growl component.
	 * 
	 * @param username
	 *            The name of the new user.
	 * @param password
	 *            The password of the new user.
	 * @param roles
	 *            The roles of the new user.
	 */
	public void addUser(final String username, final String password, final List<Role> roles) {
		this.userManagerFacade.addUser(username, password, roles);
		// TODO Check that the op was successful before adding the user to our list
		this.users.add(new User(username, roles, true));
	}

	/**
	 * This method removed the given user from the database and informs about success via the growl component.
	 * 
	 * @param username
	 *            The name of the user.
	 */
	public void removeUser(final String username) {
		this.userManagerFacade.removeUser(username);
	}

	/**
	 * This method edits the given user within the database and informs about success via the growl component.
	 * 
	 * @param username
	 *            The name of the user.
	 * @param password
	 *            The (new) password of the user.
	 * @param roles
	 *            The (new) roles of the user.
	 */
	public void editUser(final String username, final String password, final Role... roles) {
		this.userManagerFacade.editUser(username, password, roles);
	}

	/**
	 * This method initializes the bean. <b>Do not call this method manually. It will only be accessed by Spring.</b>
	 */
	protected void initialialize() {
		this.updateList();
	}

	/**
	 * Updates the list containing the available users.
	 */
	public void updateList() {
		this.users = this.userManagerFacade.getUsers();
	}

	/**
	 * This method delivers all available users.
	 * 
	 * @return All currently available users.
	 */
	public List<User> getUsers() {
		return this.users;
	}
}
